aboutsummaryrefslogtreecommitdiffstats
path: root/fg21sim/configs/manager.py
diff options
context:
space:
mode:
Diffstat (limited to 'fg21sim/configs/manager.py')
-rw-r--r--fg21sim/configs/manager.py7
1 files changed, 5 insertions, 2 deletions
diff --git a/fg21sim/configs/manager.py b/fg21sim/configs/manager.py
index 172811a..44df01c 100644
--- a/fg21sim/configs/manager.py
+++ b/fg21sim/configs/manager.py
@@ -432,8 +432,8 @@ class ConfigManager:
-------
path : str
The absolute path (if user configuration loaded) or relative
- path specified by the input key, or ``None`` if specified
- config is ``None``.
+ path specified by the input key, or ``None`` if the specified
+ config has value of ``None`` or an empty string.
Raises
------
@@ -450,6 +450,9 @@ class ConfigManager:
if value is None:
logger.warning("Specified config '%s' is None or not exist" % key)
return None
+ if value == "":
+ logger.warning("Specified config '%s' is an empty string" % key)
+ return None
if not isinstance(value, str):
msg = "Specified config '%s' is non-string: %s" % (key, value)
logger.error(msg)